Module: Warden::Auth0

Extended by:
Dry::Configurable
Defined in:
lib/warden/auth0.rb,
lib/warden/auth0/errors.rb,
lib/warden/auth0/version.rb,
lib/warden/auth0/strategy.rb,
lib/warden/auth0/env_helper.rb,
lib/warden/auth0/header_parser.rb,
lib/warden/auth0/token_decoder.rb

Overview

Auth0 authentication plugin for warden.

It consists of a strategy which tries to authenticate an user decoding a token present in the request header (as Bearer %token%). The header name is configured via token_header.

Defined Under Namespace

Modules: EnvHelper, Errors, HeaderParser Classes: Strategy, TokenDecoder

Constant Summary collapse

VERSION =
'2.0.0'